Enum Error
pub enum Error {
EndOfFile,
Io(Error),
NtoolsUtils(Error),
Nom(String),
NoTmeshInitialised,
NoTallyInitialised,
UnexpectedNumberOfKcodeValues {
expected: String,
found: usize,
message: String,
},
UnexpectedNumberOfTmeshBounds {
expected: usize,
found: usize,
message: String,
},
UnexpectedLength {
expected: usize,
found: usize,
message: String,
},
UnexpectedKeyword {
expected: String,
found: String,
message: String,
},
FailedToInferParticle {
tag: String,
message: String,
},
}Expand description
The error type for ntools-mctal
Variants
EndOfFile
Reader has reached the end of the file
Io(Error)
Errors from std::io
NtoolsUtils(Error)
Errors from ntools utilities
Nom(String)
Raw nom crate errors
NoTmeshInitialised
Check to make sure there is a Tmesh to write to. Should be unreachable.
NoTallyInitialised
Check to make sure there is a Tally to write to. Should be unreachable.
UnexpectedNumberOfKcodeValues
Unexpected number of KCODE values
UnexpectedNumberOfTmeshBounds
Unexpected number of TMESH bounds (cora + corb + corc + 3)
UnexpectedLength
Unexpected length of parsed values
UnexpectedKeyword
Unexpected maker found in a line
FailedToInferParticle
Unable to infew particle type from a string